.. include:: /_includes/wip_prolog.rst

:mod:`stix.common.structured_text` Module
=========================================

.. module:: stix.common.structured_text

Classes
-------

.. autoclass:: StructuredText
	:show-inheritance:
	:members:
